=== modified file 'drizzled/table_share.cc'
--- drizzled/table_share.cc	2010-02-25 20:20:08 +0000
+++ drizzled/table_share.cc	2010-03-15 21:50:05 +0000
@@ -43,8 +43,7 @@
 {
 
 extern size_t table_def_size;
-typedef hash_map<string, TableShare *> TableDefCache;
-TableDefCache table_def_cache;
+TableDefinitionCache table_def_cache;
 static pthread_mutex_t LOCK_table_share;
 bool table_def_inited= false;
 
@@ -110,7 +109,7 @@
   {
     const string key_string(share->table_cache_key.str,
                             share->table_cache_key.length);
-    TableDefCache::iterator iter= table_def_cache.find(key_string);
+    TableDefinitionCache::iterator iter= table_def_cache.find(key_string);
     if (iter != table_def_cache.end())
     {
       (*iter).second->free_table_share();
@@ -125,7 +124,7 @@
 {
   const string key_string(key, key_length);
 
-  TableDefCache::iterator iter= table_def_cache.find(key_string);
+  TableDefinitionCache::iterator iter= table_def_cache.find(key_string);
   if (iter != table_def_cache.end())
   {
     TableShare *share= (*iter).second;
@@ -197,7 +196,7 @@
   *error= 0;
 
   /* Read table definition from cache */
-  TableDefCache::iterator iter= table_def_cache.find(key_string);
+  TableDefinitionCache::iterator iter= table_def_cache.find(key_string);
   if (iter != table_def_cache.end())
   {
     share= (*iter).second;
@@ -218,7 +217,7 @@
   /**
    * @TODO: we need to eject something if we exceed table_def_size
    */
-  pair<TableDefCache::iterator, bool> ret=
+  pair<TableDefinitionCache::iterator, bool> ret=
     table_def_cache.insert(make_pair(key_string, share));
   if (ret.second == false)
   {
@@ -262,7 +261,7 @@
   key_length= TableShare::createKey(key, db, table_name);
 
   const string key_string(key, key_length);
-  TableDefCache::iterator iter= table_def_cache.find(key_string);
+  TableDefinitionCache::iterator iter= table_def_cache.find(key_string);
   if (iter != table_def_cache.end())
   {
     return (*iter).second;
@@ -300,4 +299,9 @@
   return false;
 }
 
+TableDefinitionCache &TableShare::getCache()
+{
+  return table_def_cache;
+}
+
 } /* namespace drizzled */

=== modified file 'drizzled/table_share.h'
--- drizzled/table_share.h	2010-03-09 22:42:17 +0000
+++ drizzled/table_share.h	2010-03-15 21:50:05 +0000
@@ -36,6 +36,8 @@
 namespace drizzled
 {
 
+typedef drizzled::hash_map<std::string, TableShare *> TableDefinitionCache;
+
 class TableShare
 {
 public:
@@ -210,7 +212,13 @@
   }
 
   uint32_t   block_size;                   /* create information */
+
   uint64_t   version;
+  uint64_t getVersion()
+  {
+    return version;
+  }
+
   uint32_t   timestamp_offset;		/* Set to offset+1 of record */
   uint32_t   reclength;			/* Recordlength */
   uint32_t   stored_rec_length;         /* Stored record length*/
@@ -309,6 +317,11 @@
   enum tmp_table_type tmp_table;
 
   uint32_t ref_count;       /* How many Table objects uses this */
+  uint32_t getTableCount()
+  {
+    return ref_count;
+  }
+
   uint32_t null_bytes;
   uint32_t last_null_bit_pos;
   uint32_t fields;				/* Number of fields */
@@ -343,9 +356,20 @@
 
   uint8_t blob_ptr_size;			/* 4 or 8 */
   bool db_low_byte_first;		/* Portable row format */
+
   bool name_lock;
+  bool isNameLock() const
+  {
+    return name_lock;
+  }
+
   bool replace_with_name_lock;
+
   bool waiting_on_cond;                 /* Protection against free */
+  bool isWaitingOnCondition()
+  {
+    return waiting_on_cond;
+  }
 
   /*
     Set of keys in use, implemented as a Bitmap.
@@ -561,6 +585,7 @@
   static void cacheStop(void);
   static void release(TableShare *share);
   static void release(const char *key, uint32_t key_length);
+  static TableDefinitionCache &getCache();
   static TableShare *getShare(const char *db, const char *table_name);
   static TableShare *getShare(Session *session, 
                               TableList *table_list, char *key,

=== modified file 'plugin/schema_dictionary/tests/r/data_dictionary.result'
--- plugin/schema_dictionary/tests/r/data_dictionary.result	2010-03-09 22:42:17 +0000
+++ plugin/schema_dictionary/tests/r/data_dictionary.result	2010-03-15 21:50:05 +0000
@@ -197,6 +197,22 @@
 #
 #
 #
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
+#
 SELECT count(*) FROM REFERENTIAL_CONSTRAINTS;
 count(*)
 #

=== added directory 'plugin/table_cache_dictionary'
=== added file 'plugin/table_cache_dictionary/dictionary.cc'
--- plugin/table_cache_dictionary/dictionary.cc	1970-01-01 00:00:00 +0000
+++ plugin/table_cache_dictionary/dictionary.cc	2010-03-15 21:50:05 +0000
@@ -0,0 +1,65 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#include "config.h"
+#include "plugin/table_cache_dictionary/dictionary.h"
+
+using namespace drizzled;
+
+static table_cache_dictionary::TableCache *tables_in_cache;
+static table_cache_dictionary::TableDefinitionCache *table_definitions;
+
+
+static int init(drizzled::plugin::Registry &registry)
+{
+  table_definitions= new(std::nothrow)table_cache_dictionary::TableDefinitionCache;
+  tables_in_cache= new(std::nothrow)table_cache_dictionary::TableCache;
+
+  registry.add(table_definitions);
+  registry.add(tables_in_cache);
+  
+  return 0;
+}
+
+static int finalize(drizzled::plugin::Registry &registry)
+{
+  registry.remove(table_definitions);
+  registry.remove(tables_in_cache);
+
+  delete table_definitions;
+  delete tables_in_cache;
+
+  return 0;
+}
+
+DRIZZLE_DECLARE_PLUGIN
+{
+  DRIZZLE_VERSION_ID,
+  "Table Cache Dictionary",
+  "1.0",
+  "Brian Aker",
+  "Data Dictionary for table and table definition cache.",
+  PLUGIN_LICENSE_GPL,
+  init,
+  finalize,
+  NULL,
+  NULL
+}
+DRIZZLE_DECLARE_PLUGIN_END;

=== added file 'plugin/table_cache_dictionary/dictionary.h'
--- plugin/table_cache_dictionary/dictionary.h	1970-01-01 00:00:00 +0000
+++ plugin/table_cache_dictionary/dictionary.h	2010-03-15 21:50:05 +0000
@@ -0,0 +1,37 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#ifndef PLUGIN_TABLE_CACHE_DICTIONARY_DICTIONARY_H
+#define PLUGIN_TABLE_CACHE_DICTIONARY_DICTIONARY_H
+
+#include <set>
+
+#include "drizzled/plugin/table_function.h"
+#include "drizzled/plugin/storage_engine.h"
+#include "drizzled/statement/select.h"
+
+#include "drizzled/session.h"
+#include "drizzled/current_session.h"
+#include "drizzled/message/schema.pb.h"
+
+#include "plugin/table_cache_dictionary/table_definition_cache.h"
+#include "plugin/table_cache_dictionary/table_cache.h"
+
+#endif /* PLUGIN_TABLE_CACHE_DICTIONARY_DICTIONARY_H */

=== added file 'plugin/table_cache_dictionary/plugin.ini'
--- plugin/table_cache_dictionary/plugin.ini	1970-01-01 00:00:00 +0000
+++ plugin/table_cache_dictionary/plugin.ini	2010-03-15 21:50:05 +0000
@@ -0,0 +1,12 @@
+[plugin]
+title=Table Cached and Table Definition Dictionary
+description= A look into the fabulous world of what is in your caches.
+load_by_default=yes
+sources= 
+  dictionary.cc
+  table_cache.cc
+  table_definition_cache.cc
+headers=
+  dictionary.h
+  table_cache.h
+  table_definition_cache.h

=== added file 'plugin/table_cache_dictionary/table_cache.cc'
--- plugin/table_cache_dictionary/table_cache.cc	1970-01-01 00:00:00 +0000
+++ plugin/table_cache_dictionary/table_cache.cc	2010-03-15 21:50:05 +0000
@@ -0,0 +1,153 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#include "config.h"
+
+#include "plugin/table_cache_dictionary/dictionary.h"
+#include "drizzled/pthread_globals.h"
+#include "drizzled/my_hash.h"
+
+using namespace drizzled;
+using namespace std;
+
+table_cache_dictionary::TableCache::TableCache() :
+  plugin::TableFunction("DATA_DICTIONARY", "TABLE_CACHE")
+{
+  add_field("SESSION_ID", plugin::TableFunction::NUMBER);
+  add_field("TABLE_SCHEMA");
+  add_field("TABLE_NAME");
+  add_field("ARCHETYPE");
+  add_field("ENGINE");
+  add_field("VERSION", plugin::TableFunction::NUMBER);
+  add_field("IS_NAME_LOCKED", plugin::TableFunction::BOOLEAN);
+  add_field("ROWS", plugin::TableFunction::NUMBER);
+  add_field("AVG_ROW_LENGTH", plugin::TableFunction::NUMBER);
+  add_field("TABLE_SIZE", plugin::TableFunction::NUMBER);
+  add_field("AUTO_INCREMENT", plugin::TableFunction::NUMBER);
+}
+
+table_cache_dictionary::TableCache::Generator::Generator(drizzled::Field **arg) :
+  drizzled::plugin::TableFunction::Generator(arg),
+  is_primed(false)
+{
+  pthread_mutex_lock(&LOCK_open); /* Optionally lock for remove tables from open_cahe if not in use */
+
+  drizzled::HASH *open_cache=
+    get_open_cache();
+
+  for (uint32_t idx= 0; idx < open_cache->records; idx++ )
+  {
+    table= (Table*) hash_element(open_cache, idx);
+    table_list.push_back(table);
+  }
+  std::sort(table_list.begin(), table_list.end(), Table::compare);
+}
+
+table_cache_dictionary::TableCache::Generator::~Generator()
+{
+  pthread_mutex_unlock(&LOCK_open); /* Optionally lock for remove tables from open_cahe if not in use */
+}
+
+bool table_cache_dictionary::TableCache::Generator::nextCore()
+{
+  if (is_primed)
+  {
+    table_list_iterator++;
+  }
+  else
+  {
+    is_primed= true;
+    table_list_iterator= table_list.begin();
+  }
+
+  if (table_list_iterator == table_list.end())
+    return false;
+
+  table= *table_list_iterator;
+
+  return true;
+}
+
+bool table_cache_dictionary::TableCache::Generator::next()
+{
+  while (not nextCore())
+  {
+    if (table_list_iterator != table_list.end())
+      continue;
+
+    return false;
+  }
+
+  return true;
+}
+
+bool table_cache_dictionary::TableCache::Generator::populate()
+{
+  if (not next())
+    return false;
+  
+  fill();
+
+  return true;
+}
+
+void table_cache_dictionary::TableCache::Generator::fill()
+{
+  /**
+    For test cases use:
+    --replace_column 1 #  6 # 8 # 9 # 10 # 11 #
+  */
+
+  /* SESSION_ID 1 */
+  if (table->getSession())
+    push(table->getSession()->getSessionId());
+  else
+    push(static_cast<int64_t>(0));
+
+  /* TABLE_SCHEMA 2 */
+  push(table->getShare()->getSchemaName());
+
+  /* TABLE_NAME  3 */
+  push(table->getShare()->getTableName());
+
+  /* ARCHETYPE  4 */
+  push(table->getShare()->getTableTypeAsString());
+
+  /* ENGINE 5 */
+  push(table->getEngine()->getName());
+
+  /* VERSION 6 */
+  push(static_cast<int64_t>(table->getShare()->version));
+
+  /* IS_NAME_LOCKED 7 */
+  push(table->getShare()->isNameLock());
+
+  /* ROWS 8 */
+  push(static_cast<uint64_t>(table->getCursor().records()));
+
+  /* AVG_ROW_LENGTH 9 */
+  push(table->getCursor().rowSize());
+
+  /* TABLE_SIZE 10 */
+  push(table->getCursor().tableSize());
+
+  /* AUTO_INCREMENT 11 */
+  push(table->getCursor().getNextInsertId());
+}

=== added file 'plugin/table_cache_dictionary/table_cache.h'
--- plugin/table_cache_dictionary/table_cache.h	1970-01-01 00:00:00 +0000
+++ plugin/table_cache_dictionary/table_cache.h	2010-03-15 21:50:05 +0000
@@ -0,0 +1,58 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#ifndef PLUGIN_TABLE_CACHE_DICTIONARY_TABLE_CACHE_H
+#define PLUGIN_TABLE_CACHE_DICTIONARY_TABLE_CACHE_H
+
+namespace table_cache_dictionary {
+
+class TableCache : public  drizzled::plugin::TableFunction
+{
+public:
+  TableCache();
+
+  class Generator : public drizzled::plugin::TableFunction::Generator 
+  {
+    bool is_primed;
+    drizzled::Table *table;
+    std::vector<drizzled::Table *> table_list;
+    std::vector<drizzled::Table *>::iterator table_list_iterator;
+
+    void fill();
+
+    bool nextCore();
+    bool next();
+
+  public:
+    bool populate();
+
+    Generator(drizzled::Field **arg);
+    ~Generator();
+  };
+
+  Generator *generator(drizzled::Field **arg)
+  {
+    return new Generator(arg);
+  }
+};
+
+} /* namespace table_cache_dictionary */
+
+#endif /* PLUGIN_TABLE_CACHE_DICTIONARY_TABLE_CACHE_H */

=== added file 'plugin/table_cache_dictionary/table_definition_cache.cc'
--- plugin/table_cache_dictionary/table_definition_cache.cc	1970-01-01 00:00:00 +0000
+++ plugin/table_cache_dictionary/table_definition_cache.cc	2010-03-15 21:50:05 +0000
@@ -0,0 +1,115 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#include "config.h"
+
+#include "plugin/table_cache_dictionary/dictionary.h"
+#include "drizzled/pthread_globals.h"
+
+using namespace drizzled;
+using namespace std;
+
+table_cache_dictionary::TableDefinitionCache::TableDefinitionCache() :
+  plugin::TableFunction("DATA_DICTIONARY", "TABLE_DEFINITION_CACHE")
+{
+  add_field("TABLE_SCHEMA");
+  add_field("TABLE_NAME");
+  add_field("VERSION", plugin::TableFunction::NUMBER);
+  add_field("TABLE_COUNT", plugin::TableFunction::NUMBER);
+  add_field("IS_NAME_LOCKED", plugin::TableFunction::BOOLEAN);
+}
+
+table_cache_dictionary::TableDefinitionCache::Generator::Generator(drizzled::Field **arg) :
+  drizzled::plugin::TableFunction::Generator(arg),
+  is_primed(false)
+{
+  pthread_mutex_lock(&LOCK_open); /* Optionally lock for remove tables from open_cahe if not in use */
+}
+
+table_cache_dictionary::TableDefinitionCache::Generator::~Generator()
+{
+  pthread_mutex_unlock(&LOCK_open); /* Optionally lock for remove tables from open_cahe if not in use */
+}
+
+bool table_cache_dictionary::TableDefinitionCache::Generator::nextCore()
+{
+  if (is_primed)
+  {
+    table_share_iterator++;
+  }
+  else
+  {
+    is_primed= true;
+    table_share_iterator= TableShare::getCache().begin();
+  }
+
+  if (table_share_iterator == TableShare::getCache().end())
+    return false;
+
+  share= (*table_share_iterator).second;
+
+  return true;
+}
+
+bool table_cache_dictionary::TableDefinitionCache::Generator::next()
+{
+  while (not nextCore())
+  {
+    if (table_share_iterator != TableShare::getCache().end())
+      continue;
+
+    return false;
+  }
+
+  return true;
+}
+
+bool table_cache_dictionary::TableDefinitionCache::Generator::populate()
+{
+  if (not next())
+    return false;
+  
+  fill();
+
+  return true;
+}
+
+void table_cache_dictionary::TableDefinitionCache::Generator::fill()
+{
+  /**
+    For test cases use:
+    --replace_column 3 # 4 # 5 #
+  */
+
+  /* TABLE_SCHEMA 1 */
+  push(share->getSchemaName());
+
+  /* TABLE_NAME  2 */
+  push(share->getTableName());
+
+  /* VERSION 3 */
+  push(static_cast<int64_t>(share->getVersion()));
+
+  /* TABLE_COUNT 4 */
+  push(static_cast<uint64_t>(share->getTableCount()));
+
+  /* IS_NAME_LOCKED */
+  push(share->isNameLock());
+}

=== added file 'plugin/table_cache_dictionary/table_definition_cache.h'
--- plugin/table_cache_dictionary/table_definition_cache.h	1970-01-01 00:00:00 +0000
+++ plugin/table_cache_dictionary/table_definition_cache.h	2010-03-15 21:50:05 +0000
@@ -0,0 +1,58 @@
+/* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; version 2 of the License.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#ifndef PLUGIN_TABLE_CACHE_DICTIONARY_TABLE_DEFINITION_CACHE_H
+#define PLUGIN_TABLE_CACHE_DICTIONARY_TABLE_DEFINITION_CACHE_H
+
+#include "drizzled/table_share.h"
+
+namespace table_cache_dictionary {
+
+class TableDefinitionCache : public  drizzled::plugin::TableFunction
+{
+public:
+  TableDefinitionCache();
+
+  class Generator : public drizzled::plugin::TableFunction::Generator 
+  {
+    bool is_primed;
+    drizzled::TableShare *share;
+    drizzled::TableDefinitionCache::iterator table_share_iterator;
+
+    void fill();
+
+    bool nextCore();
+    bool next();
+
+  public:
+    bool populate();
+
+    Generator(drizzled::Field **arg);
+    ~Generator();
+  };
+
+  Generator *generator(drizzled::Field **arg)
+  {
+    return new Generator(arg);
+  }
+};
+
+} /* namespace table_cache_dictionary */
+
+#endif /* PLUGIN_TABLE_CACHE_DICTIONARY_TABLE_DEFINITION_CACHE_H */

=== added directory 'plugin/table_cache_dictionary/tests'
=== added directory 'plugin/table_cache_dictionary/tests/r'
=== added file 'plugin/table_cache_dictionary/tests/r/table_cache.result'
--- plugin/table_cache_dictionary/tests/r/table_cache.result	1970-01-01 00:00:00 +0000
+++ plugin/table_cache_dictionary/tests/r/table_cache.result	2010-03-15 21:50:05 +0000
@@ -0,0 +1,32 @@
+show create table data_dictionary.TABLE_CACHE;
+Table	Create Table
+TABLE_CACHE	CREATE TABLE `table_cache` (
+  `SESSION_ID` bigint NOT NULL DEFAULT '0',
+  `TABLE_SCHEMA` varchar(64) NOT NULL DEFAULT '',
+  `TABLE_NAME` varchar(64) NOT NULL DEFAULT '',
+  `ARCHETYPE` varchar(64) NOT NULL DEFAULT '',
+  `ENGINE` varchar(64) NOT NULL DEFAULT '',
+  `VERSION` bigint NOT NULL DEFAULT '0',
+  `IS_NAME_LOCKED` varchar(5) NOT NULL DEFAULT '',
+  `ROWS` bigint NOT NULL DEFAULT '0',
+  `AVG_ROW_LENGTH` bigint NOT NULL DEFAULT '0',
+  `TABLE_SIZE` bigint NOT NULL DEFAULT '0',
+  `AUTO_INCREMENT` bigint NOT NULL DEFAULT '0'
+) ENGINE=FunctionEngine
+select count(*) FROM data_dictionary.TABLE_CACHE;
+count(*)
+#
+flush tables;
+select * FROM data_dictionary.TABLE_CACHE ORDER BY TABLE_SCHEMA, TABLE_NAME, ARCHETYPE;
+SESSION_ID	TABLE_SCHEMA	TABLE_NAME	ARCHETYPE	ENGINE	VERSION	IS_NAME_LOCKED	ROWS	AVG_ROW_LENGTH	TABLE_SIZE	AUTO_INCREMENT
+#	data_dictionary	table_cache	FUNCTION	FunctionEngine	#	FALSE	#	#	#	#
+create table a ( a int);
+create table b ( b int);
+select * FROM a,b;
+a	b
+select * FROM data_dictionary.TABLE_CACHE ORDER BY TABLE_SCHEMA, TABLE_NAME, ARCHETYPE;
+SESSION_ID	TABLE_SCHEMA	TABLE_NAME	ARCHETYPE	ENGINE	VERSION	IS_NAME_LOCKED	ROWS	AVG_ROW_LENGTH	TABLE_SIZE	AUTO_INCREMENT
+#		table_cache	FUNCTION	FunctionEngine	#	FALSE	#	#	#	#
+#	test	a	STANDARD	InnoDB	#	FALSE	#	#	#	#
+#	test	b	STANDARD	InnoDB	#	FALSE	#	#	#	#
+DROP TABLES a,b;

=== added file 'plugin/table_cache_dictionary/tests/r/table_definition_cache.result'
--- plugin/table_cache_dictionary/tests/r/table_definition_cache.result	1970-01-01 00:00:00 +0000
+++ plugin/table_cache_dictionary/tests/r/table_definition_cache.result	2010-03-15 21:50:05 +0000
@@ -0,0 +1,26 @@
+show create table data_dictionary.TABLE_DEFINITION_CACHE;
+Table	Create Table
+TABLE_DEFINITION_CACHE	CREATE TABLE `table_definition_cache` (
+  `TABLE_SCHEMA` varchar(64) NOT NULL DEFAULT '',
+  `TABLE_NAME` varchar(64) NOT NULL DEFAULT '',
+  `VERSION` bigint NOT NULL DEFAULT '0',
+  `TABLE_COUNT` bigint NOT NULL DEFAULT '0',
+  `IS_NAME_LOCKED` varchar(5) NOT NULL DEFAULT ''
+) ENGINE=FunctionEngine
+select count(*) FROM data_dictionary.TABLE_DEFINITION_CACHE;
+count(*)
+#
+flush tables;
+select * FROM data_dictionary.TABLE_DEFINITION_CACHE  ORDER BY TABLE_SCHEMA, TABLE_NAME;
+TABLE_SCHEMA	TABLE_NAME	VERSION	TABLE_COUNT	IS_NAME_LOCKED
+data_dictionary	table_definition_cache	#	#	#
+create table a ( a int);
+create table b ( b int);
+select * FROM a,b;
+a	b
+select * FROM data_dictionary.TABLE_DEFINITION_CACHE  ORDER BY TABLE_SCHEMA, TABLE_NAME;
+TABLE_SCHEMA	TABLE_NAME	VERSION	TABLE_COUNT	IS_NAME_LOCKED
+data_dictionary	table_definition_cache	#	#	#
+test	a	#	#	#
+test	b	#	#	#
+DROP TABLES a,b;

=== added directory 'plugin/table_cache_dictionary/tests/t'
=== added file 'plugin/table_cache_dictionary/tests/t/table_cache.test'
--- plugin/table_cache_dictionary/tests/t/table_cache.test	1970-01-01 00:00:00 +0000
+++ plugin/table_cache_dictionary/tests/t/table_cache.test	2010-03-15 21:50:05 +0000
@@ -0,0 +1,18 @@
+show create table data_dictionary.TABLE_CACHE;
+
+--replace_column 1 #
+select count(*) FROM data_dictionary.TABLE_CACHE;
+
+flush tables;
+
+--replace_column 1 #  6 # 8 # 9 # 10 # 11 #
+select * FROM data_dictionary.TABLE_CACHE ORDER BY TABLE_SCHEMA, TABLE_NAME, ARCHETYPE;
+
+create table a ( a int);
+create table b ( b int);
+--replace_column 1 #  6 # 8 # 9 # 10 # 11 #
+select * FROM a,b;
+--replace_column 1 #  6 # 8 # 9 # 10 # 11 #
+select * FROM data_dictionary.TABLE_CACHE ORDER BY TABLE_SCHEMA, TABLE_NAME, ARCHETYPE;
+
+DROP TABLES a,b;

=== added file 'plugin/table_cache_dictionary/tests/t/table_definition_cache.test'
--- plugin/table_cache_dictionary/tests/t/table_definition_cache.test	1970-01-01 00:00:00 +0000
+++ plugin/table_cache_dictionary/tests/t/table_definition_cache.test	2010-03-15 21:50:05 +0000
@@ -0,0 +1,17 @@
+show create table data_dictionary.TABLE_DEFINITION_CACHE;
+
+--replace_column 1 #
+select count(*) FROM data_dictionary.TABLE_DEFINITION_CACHE;
+
+flush tables;
+
+--replace_column 3 # 4 # 5 #
+select * FROM data_dictionary.TABLE_DEFINITION_CACHE  ORDER BY TABLE_SCHEMA, TABLE_NAME;
+
+create table a ( a int);
+create table b ( b int);
+select * FROM a,b;
+--replace_column 3 # 4 # 5 #
+select * FROM data_dictionary.TABLE_DEFINITION_CACHE  ORDER BY TABLE_SCHEMA, TABLE_NAME;
+
+DROP TABLES a,b;

=== modified file 'tests/r/data_dictionary_like_info.result'
--- tests/r/data_dictionary_like_info.result	2010-03-09 22:42:17 +0000
+++ tests/r/data_dictionary_like_info.result	2010-03-15 21:50:05 +0000
@@ -192,7 +192,7 @@
  or DATA_TYPE = 'varchar')
 group by DATA_TYPE order by DATA_TYPE, num;
 DATA_TYPE	group_concat(table_schema, '.', table_name)	num
-VARCHAR	data_dictionary.CHARACTER_SETS,data_dictionary.CHARACTER_SETS,data_dictionary.CHARACTER_SETS,data_dictionary.COLLATIONS,data_dictionary.COLLATIONS,data_dictionary.COLLATIONS,data_dictionary.COLLATIONS,data_dictionary.COLLATIONS,data_dictionary.COLUMNS,data_dictionary.COLUMNS,data_dictionary.COLUMNS,data_dictionary.COLUMNS,data_dictionary.COLUMNS,data_dictionary.COLUMNS,data_dictionary.COLUMNS,data_dictionary.COLUMNS,data_dictionary.COLUMNS,data_dictionary.COLUMNS,data_dictionary.COLUMNS,data_dictionary.COLUMNS,data_dictionary.COLUMNS,data_dictionary.COLUMNS,data_dictionary.COLUMNS,data_dictionary.COLUMNS,data_dictionary.GLOBAL_STATEMENTS,data_dictionary.GLOBAL_STATEMENTS,data_dictionary.GLOBAL_STATUS,data_dictionary.GLOBAL_STATUS,data_dictionary.GLOBAL_VARIABLES,data_dictionary.GLOBAL_VARIABLES,data_dictionary.INDEXES,data_dictionary.INDEXES,data_dictionary.INDEXES,data_dictionary.INDEXES,data_dictionary.INDEXES,data_dictionary.INDEXES,data_dictionary.INDEXES,data_dictionary.INDEXES,data_dictionary.INDEX_PART	133
+VARCHAR	data_dictionary.CHARACTER_SETS,data_dictionary.CHARACTER_SETS,data_dictionary.CHARACTER_SETS,data_dictionary.COLLATIONS,data_dictionary.COLLATIONS,data_dictionary.COLLATIONS,data_dictionary.COLLATIONS,data_dictionary.COLLATIONS,data_dictionary.COLUMNS,data_dictionary.COLUMNS,data_dictionary.COLUMNS,data_dictionary.COLUMNS,data_dictionary.COLUMNS,data_dictionary.COLUMNS,data_dictionary.COLUMNS,data_dictionary.COLUMNS,data_dictionary.COLUMNS,data_dictionary.COLUMNS,data_dictionary.COLUMNS,data_dictionary.COLUMNS,data_dictionary.COLUMNS,data_dictionary.COLUMNS,data_dictionary.COLUMNS,data_dictionary.COLUMNS,data_dictionary.GLOBAL_STATEMENTS,data_dictionary.GLOBAL_STATEMENTS,data_dictionary.GLOBAL_STATUS,data_dictionary.GLOBAL_STATUS,data_dictionary.GLOBAL_VARIABLES,data_dictionary.GLOBAL_VARIABLES,data_dictionary.INDEXES,data_dictionary.INDEXES,data_dictionary.INDEXES,data_dictionary.INDEXES,data_dictionary.INDEXES,data_dictionary.INDEXES,data_dictionary.INDEXES,data_dictionary.INDEXES,data_dictionary.INDEX_PART	141
 Warnings:
 Warning	1260	1 line(s) were cut by GROUP_CONCAT()
 create table t1(f1 char(1) not null, f2 char(9) not null);
@@ -247,12 +247,12 @@
 table_name	column_name
 SELECT MAX(table_name) FROM data_dictionary.tables;
 MAX(table_name)
-TABLE_CONSTRAINTS
+TABLE_DEFINITION_CACHE
 SELECT table_name from data_dictionary.tables
 WHERE table_name=(SELECT MAX(table_name)
 FROM data_dictionary.tables);
 table_name
-TABLE_CONSTRAINTS
+TABLE_DEFINITION_CACHE
 create table t1 (f1 int);
 create table t2 (f1 int, f2 int);
 select table_name from data_dictionary.tables

=== modified file 'tests/r/information_schema.result'
Binary files tests/r/information_schema.result and tests/r/information_schema.result differ
=== modified file 'tests/r/randgen_queries.result'
--- tests/r/randgen_queries.result	2010-03-11 16:23:09 +0000
+++ tests/r/randgen_queries.result	2010-03-15 21:50:05 +0000
@@ -115,4 +115,4 @@
 binary	binary
 select COUNT(*) from data_dictionary.tables;
 COUNT(*)
-33
+####.##.####

=== modified file 'tests/t/randgen_queries.test'
--- tests/t/randgen_queries.test	2010-03-03 19:20:02 +0000
+++ tests/t/randgen_queries.test	2010-03-15 21:50:05 +0000
@@ -64,4 +64,5 @@
                         COUNT(*) AS count FROM t1;
 
 select collation_name,character_set_name FROM data_dictionary.collations;
+--replace_column 1 ####.##.####
 select COUNT(*) from data_dictionary.tables;

